@@ -1,14 +1,13 @@
 # type: ignore[attr-defined]
-from typing import Optional
-
 from enum import Enum
+from pathlib import Path
 from random import choice
 
 import typer
 from rich.console import Console
 
 from check_reqs import version
-from check_reqs.example import hello
+from check_reqs.check_reqs import _output_rich, _process_file
 
 
 class Color(str, Enum):
@@ -37,30 +36,20 @@ def version_callback(print_version: bool) -> None:
 
 @app.command(name="")
 def main(
-    name: str = typer.Option(..., help="Person to greet."),
-    color: Optional[Color] = typer.Option(
-        None,
-        "-c",
-        "--color",
-        "--colour",
-        case_sensitive=False,
-        help="Color for print. If not specified then choice will be random.",
-    ),
-    print_version: bool = typer.Option(
-        None,
-        "-v",
-        "--version",
-        callback=version_callback,
-        is_eager=True,
-        help="Prints the version of the check_reqs package.",
+    requirements_file: Path = typer.Argument(
+        ...,
+        exists=True,
+        file_okay=True,
+        dir_okay=False,
+        readable=True,
+        resolve_path=True,
     ),
 ) -> None:
-    """Print a greeting with a giving name."""
-    if color is None:
-        color = choice(list(Color))
-
-    greeting: str = hello(name)
-    console.print(f"[bold {color}]{greeting}[/]")
+    """Check a given requirements file"""
+    status = _process_file(requirements_file)
+    _output_rich(requirements_file, status)
+    fails = sum(int(st is not None) for st in status.values())
+    raise typer.Exit(code=fails)
 
 
 if __name__ == "__main__":
